@@ -28,7 +28,7 @@
  * Class used in module tools/dbint (advanced search) and which may hold code specific for that module
  * However the class has a general principle in it which may be used in the web/export module.
  *
- * $Id: class.t3lib_fullsearch.php 7006 2010-02-23 10:25:57Z ohader $
+ * $Id: class.t3lib_fullsearch.php 7219 2010-03-29 11:42:52Z lolli $
  *
  * @author	Kasper Skaarhoj <kasperYYYY@typo3.com>
  * @coauthor	Jo Hasenau <info@cybercraft.de>
@@ -232,6 +232,7 @@ class t3lib_fullsearch {
 
 				$res = @$GLOBALS['TYPO3_DB']->sql_query($qCount);
 				if (!$GLOBALS['TYPO3_DB']->sql_error())	{
+					$GLOBALS['TYPO3_DB']->sql_free_result($res);
 					$dA = array();
 					$dA['t2_data'] = serialize(array(
 						'qC'=>$saveArr,
@@ -402,6 +403,7 @@ class t3lib_fullsearch {
 					$output.= $GLOBALS['SOBE']->doc->section('SQL error',$out,0,1);
 				} else {
 					$cPR = $this->getQueryResultCode($mQ,$res,$qGen->table);
+					$GLOBALS['TYPO3_DB']->sql_free_result($res);
 					$output.=$GLOBALS['SOBE']->doc->section($cPR['header'],$cPR['content'],0,1);
 				}
 			}
@@ -574,6 +576,11 @@ class t3lib_fullsearch {
 					// Get fields list
 				t3lib_div::loadTCA($table);
 				$conf=$TCA[$table];
+				
+					// avoid querying tables with no columns
+				if (empty($conf['columns'])) {
+					continue;
+				}
 
 				reset($conf['columns']);
 				$list=array();
@@ -598,6 +605,7 @@ class t3lib_fullsearch {
 							$rowArr[]=$this->resultRowDisplay($row,$conf,$table);
 							$lrow=$row;
 						}
+						$GLOBALS['TYPO3_DB']->sql_free_result($res);
 						$out.='<table border="0" cellpadding="2" cellspacing="1">'.$this->resultRowTitles($lrow,$conf,$table).implode(chr(10),$rowArr).'</table>';
 					}
 					$out.='<HR>';
@@ -807,6 +815,7 @@ class t3lib_fullsearch {
 					$theList .= $this->getTreeList($row['uid'], $depth-1, $begin-1, $perms_clause);
 				}
 			}
+			$GLOBALS['TYPO3_DB']->sql_free_result($res);
 		}
 		return $theList;
 	}
@@ -912,6 +921,7 @@ class t3lib_fullsearch {
 								}
 							}
 						}
+						$GLOBALS['TYPO3_DB']->sql_free_result($res);
 					}
 				}
 			} else {
@@ -983,6 +993,7 @@ class t3lib_fullsearch {
 						while ($row = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($res)) {
 							$this->tableArray[$from_table][] = $row;
 						}
+						$GLOBALS['TYPO3_DB']->sql_free_result($res);
 					}
 					reset($this->tableArray[$from_table]);
 					foreach ($this->tableArray[$from_table] as $key => $val) {
