@@ -2,7 +2,7 @@
 /***************************************************************
 *  Copyright notice
 *
-*  (c) 2001-2008 Christian Jul Jensen (christian@typo3.com)
+*  (c) 2001-2009 Christian Jul Jensen (christian@typo3.com)
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
@@ -27,7 +27,7 @@
 /**
  * Class for generating front end for building queries
  *
- * $Id: class.t3lib_querygenerator.php 4881 2009-01-28 13:58:15Z benni $
+ * $Id: class.t3lib_querygenerator.php 7006 2010-02-23 10:25:57Z ohader $
  *
  * @author	Christian Jul Jensen <christian@typo3.com>
  * @author	Kasper Skaarhoj <kasperYYYY@typo3.com>
@@ -289,14 +289,14 @@ class t3lib_queryGenerator	{
 				$this->fields[$fN] = $fC['config'];
 				$this->fields[$fN]['exclude'] = $fC['exclude'];
 				if (is_array($fC) && $fC['label'])	{
-					$this->fields[$fN]['label'] = ereg_replace(':$','',trim($GLOBALS['LANG']->sL($fC['label'])));
+					$this->fields[$fN]['label'] = rtrim(trim($GLOBALS['LANG']->sL($fC['label'])), ':');
 					switch ($this->fields[$fN]['type'])	{
 						case 'input':
-							if (eregi('int|year', $this->fields[$fN]['eval']))	{
+							if (preg_match('/int|year/i', $this->fields[$fN]['eval']))	{
 								$this->fields[$fN]['type']='number';
-							} elseif (eregi('time', $this->fields[$fN]['eval']))	{
+							} elseif (preg_match('/time/i', $this->fields[$fN]['eval']))	{
 								$this->fields[$fN]['type'] = 'time';
-							} elseif (eregi('date', $this->fields[$fN]['eval']))	{
+							} elseif (preg_match('/date/i', $this->fields[$fN]['eval']))	{
 								$this->fields[$fN]['type']='date';
 							} else {
 								$this->fields[$fN]['type']='text';
@@ -626,7 +626,7 @@ class t3lib_queryGenerator	{
 				case 'date':
 					$lineHTML.=$this->mkTypeSelect($this->name.$subscript.'[type]',$fName);
 					$lineHTML.=$this->mkCompSelect($this->name.$subscript.'[comparison]',$conf['comparison'],$conf['negate']?1:0);
-					$lineHTML.='<input type="checkbox"'.($conf['negate']?' checked':'').' name="'.$this->name.$subscript.'[negate]'.'" onClick="submit();">';
+					$lineHTML.='<input type="checkbox" class="checkbox"' . ($conf['negate']?' checked':'').' name="'.$this->name.$subscript.'[negate]'.'" onClick="submit();">';
 
 					if ($conf['comparison']==100 || $conf['comparison']==101)	{	// between
 						$lineHTML.='<input type="text" name="'.$this->name.$subscript.'[inputValue]_hr'.'" value="'.strftime('%e-%m-%Y', $conf['inputValue']).'" '.$GLOBALS['TBE_TEMPLATE']->formWidth(10).' onChange="typo3form.fieldGet(\''.$this->name.$subscript.'[inputValue]\', \'date\', \'\', 0,0);"><input type="hidden" value="'.htmlspecialchars($conf['inputValue']).'" name="'.$this->name.$subscript.'[inputValue]'.'">';
@@ -642,7 +642,7 @@ class t3lib_queryGenerator	{
 					$lineHTML.=$this->mkTypeSelect($this->name.$subscript.'[type]', $fName);
 					$lineHTML.=$this->mkCompSelect($this->name.$subscript.'[comparison]', $conf['comparison'], $conf['negate']?1:0);
 
-					$lineHTML.='<input type="checkbox"'.($conf['negate']?' checked':'').' name="'.$this->name.$subscript.'[negate]'.'" onClick="submit();">';
+					$lineHTML.='<input type="checkbox" class="checkbox"'.($conf['negate']?' checked':'').' name="'.$this->name.$subscript.'[negate]'.'" onClick="submit();">';
 					if ($conf['comparison']==100 || $conf['comparison']==101)	{	// between:
 						$lineHTML.='<input type="text" name="'.$this->name.$subscript.'[inputValue]_hr'.'" value="'.strftime('%H:%M %e-%m-%Y', $conf['inputValue']).'" '.$GLOBALS['TBE_TEMPLATE']->formWidth(10).' onChange="typo3form.fieldGet(\''.$this->name.$subscript.'[inputValue]\', \'datetime\', \'\', 0,0);"><input type="hidden" value="'.htmlspecialchars($conf['inputValue']).'" name="'.$this->name.$subscript.'[inputValue]'.'">';
 						$lineHTML.='<input type="text" name="'.$this->name.$subscript.'[inputValue1]_hr'.'" value="'.strftime('%H:%M %e-%m-%Y', $conf['inputValue1']).'" '.$GLOBALS['TBE_TEMPLATE']->formWidth(10).' onChange="typo3form.fieldGet(\''.$this->name.$subscript.'[inputValue1]\', \'datetime\', \'\', 0,0);"><input type="hidden" value="'.htmlspecialchars($conf['inputValue1']).'" name="'.$this->name.$subscript.'[inputValue1]'.'">';
@@ -658,7 +658,7 @@ class t3lib_queryGenerator	{
 				case 'relation':
 					$lineHTML.=$this->mkTypeSelect($this->name.$subscript.'[type]', $fName);
 					$lineHTML.=$this->mkCompSelect($this->name.$subscript.'[comparison]', $conf['comparison'], $conf['negate']?1:0);
-					$lineHTML.='<input type="checkbox"'.($conf['negate']?' checked':'').' name="'.$this->name.$subscript.'[negate]'.'" onClick="submit();">';
+					$lineHTML.='<input type="checkbox" class="checkbox"'.($conf['negate']?' checked':'').' name="'.$this->name.$subscript.'[negate]'.'" onClick="submit();">';
 					if ($conf['comparison']==68 || $conf['comparison']==69 || $conf['comparison']==162 || $conf['comparison']==163)	{
 						$lineHTML.='<select name="'.$this->name.$subscript.'[inputValue]'.'[]" style="vertical-align:top;" size="5" multiple>';
 					} elseif ($conf['comparison']==66 || $conf['comparison']==67)	{
@@ -677,7 +677,7 @@ class t3lib_queryGenerator	{
 				case 'files':
 					$lineHTML.= $this->mkTypeSelect($this->name.$subscript.'[type]', $fName);
 					$lineHTML.= $this->mkCompSelect($this->name.$subscript.'[comparison]', $conf['comparison'], $conf['negate']?1:0);
-					$lineHTML.= '<input type="checkbox"'.($conf['negate']?' checked':'').' name="'.$this->name.$subscript.'[negate]'.'" onClick="submit();">';
+					$lineHTML.= '<input type="checkbox" class="checkbox"'.($conf['negate']?' checked':'').' name="'.$this->name.$subscript.'[negate]'.'" onClick="submit();">';
 					if ($conf['comparison']==68 || $conf['comparison']==69)	{
 						$lineHTML .= '<select name="'.$this->name.$subscript.'[inputValue]'.'[]" style="vertical-align:top;" size="5" multiple>';
 					} else {
@@ -692,13 +692,13 @@ class t3lib_queryGenerator	{
 				case 'boolean':
 					$lineHTML .= $this->mkTypeSelect($this->name.$subscript.'[type]', $fName);
 					$lineHTML .= $this->mkCompSelect($this->name.$subscript.'[comparison]', $conf['comparison'], $conf['negate']?1:0);
-					$lineHTML .= '<input type="checkbox"'.($conf['negate']?' checked':'').' name="'.$this->name.$subscript.'[negate]'.'" onClick="submit();">';
+					$lineHTML .= '<input type="checkbox" class="checkbox"'.($conf['negate']?' checked':'').' name="'.$this->name.$subscript.'[negate]'.'" onClick="submit();">';
 					$lineHTML .= '<input type="hidden" value="1" name="'.$this->name.$subscript.'[inputValue]'.'"'.$GLOBALS['TBE_TEMPLATE']->formWidth(10).'>';
 				break;
 				default:
 					$lineHTML .= $this->mkTypeSelect($this->name.$subscript.'[type]', $fName);
 					$lineHTML .= $this->mkCompSelect($this->name.$subscript.'[comparison]', $conf['comparison'], $conf['negate']?1:0);
-					$lineHTML .= '<input type="checkbox"'.($conf['negate']?' checked':'').' name="'.$this->name.$subscript.'[negate]'.'" onClick="submit();">';
+					$lineHTML .= '<input type="checkbox" class="checkbox"'.($conf['negate']?' checked':'').' name="'.$this->name.$subscript.'[negate]'.'" onClick="submit();">';
 					if ($conf['comparison']==37 || $conf['comparison']==36)	{	// between:
 						$lineHTML.='<input type="text" value="'.htmlspecialchars($conf['inputValue']).'" name="'.$this->name.$subscript.'[inputValue]'.'"'.$GLOBALS['TBE_TEMPLATE']->formWidth(5).'>
 						<input type="text" value="'.htmlspecialchars($conf['inputValue1']).'" name="'.$this->name.$subscript.'[inputValue1]'.'"'.$GLOBALS['TBE_TEMPLATE']->formWidth(5).'>';	// onChange='submit();'
@@ -710,16 +710,16 @@ class t3lib_queryGenerator	{
 			if($fType != 'ignore') {
 				$lineHTML .= $this->updateIcon();
 				if ($loopcount)	{
-					$lineHTML .= '<input type="image" border="0" src="'.$GLOBALS['BACK_PATH'].'gfx/garbage.gif" class="absmiddle" width="11" height="12" hspace="3" vspace="3" title="Remove condition" name="qG_del'.$subscript.'">';
+					$lineHTML .= '<input type="image" border="0" ' . t3lib_iconWorks::skinImg($GLOBALS['BACK_PATH'], 'gfx/garbage.gif', 'width="11" height="12"') . 'title="Remove condition" name="qG_del'.$subscript.'">';
 				}
-				$lineHTML .= '<input type="image" border="0" src="'.$GLOBALS['BACK_PATH'].'gfx/add.gif" class="absmiddle" width="12" height="12" hspace="3" vspace="3" title="Add condition" name="qG_ins'.$subscript.'">';
-				if($c!=0) $lineHTML.= '<input type="image" border="0" src="'.$GLOBALS['BACK_PATH'].'gfx/pil2up.gif" class="absmiddle" width="12" height="7" hspace="3" vspace="3" title="Move up" name="qG_up'.$subscript.'">';
+				$lineHTML .= '<input type="image" border="0" ' . t3lib_iconWorks::skinImg($GLOBALS['BACK_PATH'], 'gfx/add.gif', 'width="12" height="12"') . ' title="Add condition" name="qG_ins'.$subscript.'">';
+				if($c!=0) $lineHTML.= '<input type="image" border="0" ' . t3lib_iconWorks::skinImg($GLOBALS['BACK_PATH'], 'gfx/pil2up.gif', 'width="12" height="7"') . ' title="Move up" name="qG_up'.$subscript.'">';
 
 				if($c!=0 && $fType!='newlevel') {
-					$lineHTML.= '<input type="image" border="0" src="'.$GLOBALS['BACK_PATH'].'gfx/pil2right.gif" class="absmiddle" height="12" width="7" hspace="3" vspace="3" title="New level" name="qG_nl'.$subscript.'">';
+					$lineHTML.= '<input type="image" border="0" ' . t3lib_iconWorks::skinImg($GLOBALS['BACK_PATH'], 'gfx/pil2right.gif', 'height="12" width="7"') . ' title="New level" name="qG_nl'.$subscript.'">';
 				}
 				if($fType=='newlevel') {
-					$lineHTML.= '<input type="image" border="0" src="'.$GLOBALS['BACK_PATH'].'gfx/pil2left.gif" class="absmiddle" height="12" width="7" hspace="3" vspace="3" title="Collapse new level" name="qG_remnl'.$subscript.'">';
+					$lineHTML.= '<input type="image" border="0" ' . t3lib_iconWorks::skinImg($GLOBALS['BACK_PATH'], 'gfx/pil2left.gif',  'height="12" width="7"') . ' title="Collapse new level" name="qG_remnl'.$subscript.'">';
 				}
 
 				$codeArr[$arrCount]['html'] = $lineHTML;
@@ -905,7 +905,7 @@ class t3lib_queryGenerator	{
 					} else {
 						$where_clause = 'uid';
 						if (!$GLOBALS['SOBE']->MOD_SETTINGS['show_deleted'])	{
-    							$where_clause .= t3lib_BEfunc::deleteClause($from_table);
+							$where_clause .= t3lib_BEfunc::deleteClause($from_table);
 						}
 					}
 					$orderBy = 'uid';
@@ -976,7 +976,7 @@ class t3lib_queryGenerator	{
 	 * @return	[type]		...
 	 */
 	function formatQ($str)	{
-		return '<font size="1" face="verdana" color="maroon"><i>'.$str.'</i></font>';
+		return '<font size="1" face="verdana" color="maroon"><i>' . htmlspecialchars($str) . '</i></font>';
 	}
 
 	/**
@@ -1069,7 +1069,7 @@ class t3lib_queryGenerator	{
 	 */
 	function mkFieldToInputSelect($name,$fieldName)	{
 		$out='<input type="Text" value="'.htmlspecialchars($fieldName).'" name="'.$name.'"'.$GLOBALS['TBE_TEMPLATE']->formWidth().'>'.$this->updateIcon();
-		$out.='<a href="#" onClick="document.forms[0][\''.$name.'\'].value=\'\';return false;"><img src="'.$GLOBALS['BACK_PATH'].'gfx/garbage.gif" class="absmiddle" width="11" height="12" hspace="3" vspace="3" title="Clear list" border="0"></a>';
+		$out.='<a href="#" onClick="document.forms[0][\''.$name.'\'].value=\'\';return false;"><img ' . t3lib_iconWorks::skinImg($GLOBALS['BACK_PATH'], 'gfx/garbage.gif', 'width="11" height="12"') . ' class="absmiddle" title="Clear list" border="0"></a>';
 		$out.='<BR><select name="_fieldListDummy" size="5" onChange="document.forms[0][\''.$name.'\'].value+=\',\'+this.value">';
 		reset($this->fields);
 		while(list($key,)=each($this->fields)) {
@@ -1278,7 +1278,7 @@ class t3lib_queryGenerator	{
 	 * @return	[type]		...
 	 */
 	function updateIcon()	{
-		return '<input type="image" border="0" src="'.$GLOBALS['BACK_PATH'].'gfx/refresh_n.gif" class="absmiddle" width="14" height="14" hspace="3" vspace="3" title="Update" name="just_update">';
+		return '<input type="image" border="0" ' . t3lib_iconWorks::skinImg($GLOBALS['BACK_PATH'], 'gfx/refresh_n.gif',  'width="14" height="14"') . ' title="Update" name="just_update">';
 	}
 
 	/**
@@ -1416,7 +1416,7 @@ class t3lib_queryGenerator	{
 				';
 			}
 		}
-		$out='<table border="0" cellpadding="3" cellspacing="1">'.$out.'</table>';
+		$out='<table border="0" cellpadding="3" cellspacing="1" class="qg-make-query">'.$out.'</table>';
 		$out.=$this->JSbottom($this->formName);
 		return $out;
 	}
@@ -1513,6 +1513,7 @@ class t3lib_queryGenerator	{
 			<script language="javascript" type="text/javascript">
 				TBE_EDITOR.formname = "'.$formname.'";
 				TBE_EDITOR.formnameUENC = "'.rawurlencode($formname).'";
+				TBE_EDITOR.backend_interface = "'.$GLOBALS['BE_USER']->uc['interfaceSetup'].'";
 				'.$this->extJSCODE.'
 			</script>';
 			return $out;
@@ -1534,4 +1535,5 @@ class t3lib_queryGenerator	{
 if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['t3lib/class.t3lib_querygenerator.php'])	{
 	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['t3lib/class.t3lib_querygenerator.php']);
 }
+
 ?>
