@@ -2,7 +2,7 @@
 /***************************************************************
 *  Copyright notice
 *
-*  (c) 1999-2005 Kasper Skaarhoj (kasperYYYY@typo3.com)
+*  (c) 1999-2009 Kasper Skaarhoj (kasperYYYY@typo3.com)
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
@@ -27,7 +27,7 @@
 /**
  * This script contains the parent class, 'pibase', providing an API with the most basic methods for frontend plugins
  *
- * $Id: class.tslib_pibase.php 1421 2006-04-10 09:27:15Z mundaun $
+ * $Id: class.tslib_pibase.php 6684 2009-12-19 15:26:00Z xperseguers $
  * Revised for TYPO3 3.6 June/2003 by Kasper Skaarhoj
  * XHTML compliant
  *
@@ -106,17 +106,6 @@
 
 
 
-
-
-
-
-
-
-
-
-
-
-
 
 
 /**
@@ -132,7 +121,12 @@
 class tslib_pibase {
 
 		// Reserved variables:
-	var $cObj;		// The backReference to the mother cObj object set at call time
+	/**
+	 * The backReference to the mother cObj object set at call time
+	 *
+	 * @var tslib_cObj
+	 */
+	var $cObj;
 	var $prefixId;		// Should be same as classname of the plugin, used for CSS classes, variables
 	var $scriptRelPath;	// Path to the plugin class script relative to extension directory, eg. 'pi1/class.tx_newfaq_pi1.php'
 	var $extKey;		// Extension key.
@@ -215,7 +209,7 @@ class tslib_pibase {
 
 			// Setting piVars:
 		if ($this->prefixId)	{
-			$this->piVars = t3lib_div::GParrayMerged($this->prefixId);
+			$this->piVars = t3lib_div::_GPmerged($this->prefixId);
 
 				// cHash mode check
 				// IMPORTANT FOR CACHED PLUGINS (USER cObject): As soon as you generate cached plugin output which depends on parameters (eg. seeing the details of a news item) you MUST check if a cHash value is set.
@@ -310,7 +304,7 @@ class tslib_pibase {
 		$conf['useCacheHash'] = $this->pi_USER_INT_obj ? 0 : $cache;
 		$conf['no_cache'] = $this->pi_USER_INT_obj ? 0 : !$cache;
 		$conf['parameter'] = $altPageId ? $altPageId : ($this->pi_tmpPageId ? $this->pi_tmpPageId : $GLOBALS['TSFE']->id);
-		$conf['additionalParams'] = $this->conf['parent.']['addParams'].t3lib_div::implodeArrayForUrl('',$urlParameters,'',1).$this->pi_moreParams;
+		$conf['additionalParams'] = $this->conf['parent.']['addParams'].t3lib_div::implodeArrayForUrl('', $urlParameters, '', true).$this->pi_moreParams;
 
 		return $this->cObj->typoLink($str, $conf);
 	}
@@ -399,7 +393,7 @@ class tslib_pibase {
 	 * @return	string		The processed input string, modified IF a <a> tag was found
 	 */
 	function pi_openAtagHrefInJSwindow($str,$winName='',$winParams='width=670,height=500,status=0,menubar=0,scrollbars=1,resizable=1')	{
-		if (eregi('(.*)(<a[^>]*>)(.*)',$str,$match))	{
+		if (preg_match('/(.*)(<a[^>]*>)(.*)/i',$str,$match))	{
 			$aTagContent = t3lib_div::get_tag_attributes($match[2]);
 			$match[2]='<a href="#" onclick="'.
 				htmlspecialchars('vHWin=window.open(\''.$GLOBALS['TSFE']->baseUrlWrap($aTagContent['href']).'\',\''.($winName?$winName:md5($aTagContent['href'])).'\',\''.$winParams.'\');vHWin.focus();return false;').
@@ -442,9 +436,7 @@ class tslib_pibase {
 	 * disabledLinkWrap, inactiveLinkWrap, activeLinkWrap, browseLinksWrap, showResultsWrap, showResultsNumbersWrap, browseBoxWrap.
 	 *
 	 * If $wrapArr['showResultsNumbersWrap'] is set, the formatting string is expected to hold template markers (###FROM###, ###TO###, ###OUT_OF###, ###FROM_TO###, ###CURRENT_PAGE###, ###TOTAL_PAGES###)
-	 * otherwise the formatting sting is expected to hold sprintf-markers (%s) for from, to, outof (in that sequence)
-	 *
-	 * 										otherwise wrapping is totally controlled/modified by this array
+	 * otherwise the formatting string is expected to hold sprintf-markers (%s) for from, to, outof (in that sequence)
 	 *
 	 * @param	integer		determines how the results of the pagerowser will be shown. See description below
 	 * @param	string		Attributes for the table tag which is wrapped around the table cells containing the browse links
@@ -453,7 +445,7 @@ class tslib_pibase {
 	 * @param	boolean		enable htmlspecialchars() for the pi_getLL function (set this to FALSE if you want f.e use images instead of text for links like 'previous' and 'next').
 	 * @return	string		Output HTML-Table, wrapped in <div>-tags with a class attribute (if $wrapArr is not passed,
 	 */
-	function pi_list_browseresults($showResultCount=1,$tableParams='',$wrapArr=array(), $pointerName = 'pointer', $hscText = TRUE)	{
+	function pi_list_browseresults($showResultCount=1, $tableParams='', $wrapArr=array(), $pointerName='pointer', $hscText=TRUE)	{
 
 		// example $wrapArr-array how it could be traversed from an extension
 		/* $wrapArr = array(
@@ -556,7 +548,7 @@ class tslib_pibase {
 				}
 			}
 			if ($pointer<$totalPages-1 || $showFirstLast)	{
-				if ($pointer==$totalPages-1) { // Link to next page
+				if ($pointer>=$totalPages-1) { // Link to next page
 					$links[]=$this->cObj->wrap($this->pi_getLL('pi_list_browseresults_next','Next >',$hscText),$wrapper['disabledLinkWrap']);
 				} else {
 					$links[]=$this->cObj->wrap($this->pi_linkTP_keepPIvars($this->pi_getLL('pi_list_browseresults_next','Next >',$hscText),array($pointerName => $pointer+1),$pi_isOnlyFields),$wrapper['inactiveLinkWrap']);
@@ -648,8 +640,7 @@ class tslib_pibase {
 	 */
 	function pi_list_modeSelector($items=array(),$tableParams='')	{
 		$cells=array();
-		reset($items);
-		while(list($k,$v)=each($items))	{
+		foreach ($items as $k => $v) {
 			$cells[]='
 					<td'.($this->piVars['mode']==$k?$this->pi_classParam('modeSelector-SCell'):'').'><p>'.
 				$this->pi_linkTP_keepPIvars(htmlspecialchars($v),array('mode'=>$k),$this->pi_isOnlyFields($this->pi_isOnlyFields)).
@@ -770,12 +761,20 @@ class tslib_pibase {
 	 * Returns the class-attribute with the correctly prefixed classname
 	 * Using pi_getClassName()
 	 *
-	 * @param	string		The class name (suffix)
+	 * @param	string		The class name(s) (suffix) - separate multiple classes with commas
+	 * @param	string		Additional class names which should not be prefixed - separate multiple classes with commas
 	 * @return	string		A "class" attribute with value and a single space char before it.
 	 * @see pi_getClassName()
 	 */
-	function pi_classParam($class)	{
-		return ' class="'.$this->pi_getClassName($class).'"';
+	function pi_classParam($class, $addClasses='')	{
+		$output = '';
+		foreach (t3lib_div::trimExplode(',',$class) as $v)	{
+			$output.= ' '.$this->pi_getClassName($v);
+		}
+		foreach (t3lib_div::trimExplode(',',$addClasses) as $v)	{
+			$output.= ' '.$v;
+		}
+		return ' class="'.trim($output).'"';
 	}
 
 	/**
@@ -785,10 +784,13 @@ class tslib_pibase {
 	 * @param	string		$data: CSS data
 	 * @param	string		If $selector is set to any CSS selector, eg 'P' or 'H1' or 'TABLE' then the style $data will regard those HTML-elements only
 	 * @return	void
-	 * @deprecated		I think this function should not be used (and probably isn't used anywhere). It was a part of a concept which was left behind quite quickly.
+	 * @deprecated since TYPO3 3.6, this function will be removed in TYPO3 4.5, I think this function should not be used (and probably isn't used anywhere). It was a part of a concept which was left behind quite quickly.
+	 * @obsolete
 	 * @private
 	 */
 	function pi_setClassStyle($class,$data,$selector='')	{
+		t3lib_div::logDeprecatedFunction();
+
 		$GLOBALS['TSFE']->setCSS($this->pi_getClassName($class).($selector?' '.$selector:''),'.'.$this->pi_getClassName($class).($selector?' '.$selector:'').' {'.$data.'}');
 	}
 
@@ -945,10 +947,11 @@ class tslib_pibase {
 	 * @return	string		The value from LOCAL_LANG.
 	 */
 	function pi_getLL($key,$alt='',$hsc=FALSE)	{
+			// The "from" charset of csConv() is only set for strings from TypoScript via _LOCAL_LANG
 		if (isset($this->LOCAL_LANG[$this->LLkey][$key]))	{
-			$word = $GLOBALS['TSFE']->csConv($this->LOCAL_LANG[$this->LLkey][$key], $this->LOCAL_LANG_charset[$this->LLkey][$key]);	// The "from" charset is normally empty and thus it will convert from the charset of the system language, but if it is set (see ->pi_loadLL()) it will be used.
+			$word = $GLOBALS['TSFE']->csConv($this->LOCAL_LANG[$this->LLkey][$key], $this->LOCAL_LANG_charset[$this->LLkey][$key]);
 		} elseif ($this->altLLkey && isset($this->LOCAL_LANG[$this->altLLkey][$key]))	{
-			$word = $GLOBALS['TSFE']->csConv($this->LOCAL_LANG[$this->altLLkey][$key], $this->LOCAL_LANG_charset[$this->altLLkey][$key]);	// The "from" charset is normally empty and thus it will convert from the charset of the system language, but if it is set (see ->pi_loadLL()) it will be used.
+			$word = $GLOBALS['TSFE']->csConv($this->LOCAL_LANG[$this->altLLkey][$key], $this->LOCAL_LANG_charset[$this->altLLkey][$key]);
 		} elseif (isset($this->LOCAL_LANG['default'][$key]))	{
 			$word = $this->LOCAL_LANG['default'][$key];	// No charset conversion because default is english and thereby ASCII
 		} else {
@@ -969,28 +972,26 @@ class tslib_pibase {
 	 */
 	function pi_loadLL()	{
 		if (!$this->LOCAL_LANG_loaded && $this->scriptRelPath)	{
-			$basePath = t3lib_extMgm::extPath($this->extKey).dirname($this->scriptRelPath).'/locallang.php';
+			$basePath = 'EXT:' . $this->extKey . '/' . dirname($this->scriptRelPath) . '/locallang.xml';
 
-				// php or xml as source: In any case the charset will be that of the system language.
-				// However, this function guarantees only return output for default language plus the specified language (which is different from how 3.7.0 dealt with it)
-			$this->LOCAL_LANG = t3lib_div::readLLfile($basePath,$this->LLkey);
+				// Read the strings in the required charset (since TYPO3 4.2)
+			$this->LOCAL_LANG = t3lib_div::readLLfile($basePath,$this->LLkey,$GLOBALS['TSFE']->renderCharset);
 			if ($this->altLLkey)	{
 				$tempLOCAL_LANG = t3lib_div::readLLfile($basePath,$this->altLLkey);
 				$this->LOCAL_LANG = array_merge(is_array($this->LOCAL_LANG) ? $this->LOCAL_LANG : array(),$tempLOCAL_LANG);
 			}
 
 				// Overlaying labels from TypoScript (including fictitious language keys for non-system languages!):
-			if (is_array($this->conf['_LOCAL_LANG.']))	{
-				reset($this->conf['_LOCAL_LANG.']);
-				while(list($k,$lA)=each($this->conf['_LOCAL_LANG.']))	{
+			$confLL = $this->conf['_LOCAL_LANG.'];
+			if (is_array($confLL)) {
+				foreach ($confLL as $k => $lA) {
 					if (is_array($lA))	{
 						$k = substr($k,0,-1);
 						foreach($lA as $llK => $llV)	{
 							if (!is_array($llV))	{
 								$this->LOCAL_LANG[$k][$llK] = $llV;
-								if ($k != 'default')	{
-									$this->LOCAL_LANG_charset[$k][$llK] = $GLOBALS['TYPO3_CONF_VARS']['BE']['forceCharset'];	// For labels coming from the TypoScript (database) the charset is assumed to be "forceCharset" and if that is not set, assumed to be that of the individual system languages (thus no conversion)
-								}
+									// For labels coming from the TypoScript (database) the charset is assumed to be "forceCharset" and if that is not set, assumed to be that of the individual system languages
+								$this->LOCAL_LANG_charset[$k][$llK] = $GLOBALS['TYPO3_CONF_VARS']['BE']['forceCharset'] ? $GLOBALS['TYPO3_CONF_VARS']['BE']['forceCharset'] : $GLOBALS['TSFE']->csConvObj->charSetArray[$k];
 							}
 						}
 					}
@@ -1043,7 +1044,7 @@ class tslib_pibase {
 	 * @param	boolean		If set, the function will return the query not as a string but array with the various parts.
 	 * @return	mixed		The query build.
 	 * @access private
-	 * @deprecated		Use pi_exec_query() instead!
+	 * @deprecated since TYPO3 3.6, this function will be removed in TYPO3 4.5, use pi_exec_query() instead!
 	 */
 	function pi_list_query($table,$count=0,$addWhere='',$mm_cat='',$groupBy='',$orderBy='',$query='',$returnQueryArray=FALSE)	{
 
@@ -1066,7 +1067,7 @@ class tslib_pibase {
 		}
 
 			// Split the "FROM ... WHERE" string so we get the WHERE part and TABLE names separated...:
-		list($TABLENAMES,$WHERE) = spliti('WHERE', trim($query), 2);
+		list($TABLENAMES, $WHERE) = preg_split('/WHERE/i', trim($query), 2);
 		$TABLENAMES = trim(substr(trim($TABLENAMES),5));
 		$WHERE = trim($WHERE);
 
@@ -1163,18 +1164,23 @@ class tslib_pibase {
 	 * @param	integer		$recursive is an integer >=0 telling how deep to dig for pids under each entry in $pid_list
 	 * @return	string		List of PID values (comma separated)
 	 */
-	function pi_getPidList($pid_list,$recursive=0)	{
-		if (!strcmp($pid_list,''))	$pid_list = $GLOBALS['TSFE']->id;
-		$recursive = t3lib_div::intInRange($recursive,0);
+	function pi_getPidList($pid_list, $recursive = 0) {
+		if (!strcmp($pid_list, '')) {
+			$pid_list = $GLOBALS['TSFE']->id;
+		}
 
-		$pid_list_arr = array_unique(t3lib_div::trimExplode(',',$pid_list,1));
-		$pid_list = array();
+		$recursive = t3lib_div::intInRange($recursive, 0);
 
-		foreach($pid_list_arr as $val)	{
-			$val = t3lib_div::intInRange($val,0);
-			if ($val)	{
-				$_list = $this->cObj->getTreeList(-1*$val, $recursive);
-				if ($_list)		$pid_list[] = $_list;
+		$pid_list_arr = array_unique(t3lib_div::trimExplode(',', $pid_list, 1));
+		$pid_list     = array();
+
+		foreach($pid_list_arr as $val) {
+			$val = t3lib_div::intInRange($val, 0);
+			if ($val) {
+				$_list = $this->cObj->getTreeList(-1 * $val, $recursive);
+				if ($_list) {
+					$pid_list[] = $_list;
+				}
 			}
 		}
 
@@ -1191,7 +1197,7 @@ class tslib_pibase {
 	function pi_prependFieldsWithTable($table,$fieldList)	{
 		$list=t3lib_div::trimExplode(',',$fieldList,1);
 		$return=array();
-		while(list(,$listItem)=each($list))	{
+		foreach ($list as $listItem) {
 			$return[]=$table.'.'.$listItem;
 		}
 		return implode(',',$return);
@@ -1257,7 +1263,7 @@ class tslib_pibase {
 
 		$fList = t3lib_div::trimExplode(',',$fList,1);
 		$tempPiVars = $this->piVars;
-		while(list(,$k)=each($fList))	{
+		foreach ($fList as $k) {
 			if (!t3lib_div::testInt($tempPiVars[$k]) || $tempPiVars[$k]<$lowerThan)		unset($tempPiVars[$k]);
 		}
 		if (!count($tempPiVars))	return 1;
@@ -1274,8 +1280,7 @@ class tslib_pibase {
 	 */
 	function pi_autoCache($inArray)	{
 		if (is_array($inArray))	{
-			reset($inArray);
-			while(list($fN,$fV)=each($inArray))	{
+			foreach ($inArray as $fN => $fV) {
 				if (!strcmp($inArray[$fN],''))	{
 					unset($inArray[$fN]);
 				} elseif (is_array($this->pi_autoCacheFields[$fN]))	{
@@ -1385,4 +1390,5 @@ class tslib_pibase {
 }
 
 // NO extension of class - does not make sense here.
-?>
+
+?>
\ No newline at end of file
