@@ -2,7 +2,7 @@
 /***************************************************************
 *  Copyright notice
 *
-*  (c) 2007-2008 Steffen Kamper <info@sk-typo3.de>
+*  (c) 2007-2009 Steffen Kamper <info@sk-typo3.de>
 *  Based on Newloginbox (c) 2002-2004 Kasper Skaarhoj <kasper@typo3.com>
 *
 *  All rights reserved
@@ -25,10 +25,6 @@
 *
 *  The code was adapted from newloginbox, see manual for detailed description
 ***************************************************************/
-
-require_once(PATH_tslib.'class.tslib_pibase.php');
-
-
 /**
  * Plugin 'Website User Login' for the 'felogin' extension.
  *
@@ -40,11 +36,15 @@ class tx_felogin_pi1 extends tslib_pibase {
 	var $prefixId      = 'tx_felogin_pi1';		// Same as class name
 	var $scriptRelPath = 'pi1/class.tx_felogin_pi1.php';	// Path to this script relative to the extension dir.
 	var $extKey        = 'felogin';	// The extension key.
-	var $pi_checkCHash = true;
-	var $userIsLoggedIn;	// Is user logged in?
-	var $template;
-	var $uploadDir;
-	var $redirectUrl;
+	public $pi_checkCHash = false;
+	public $pi_USER_INT_obj = true;
+
+	protected $userIsLoggedIn;	// Is user logged in?
+	protected $template;	// holds the template for FE rendering
+	protected $uploadDir;	// upload dir, used for flexform template files
+	protected $redirectUrl;	// URL for the redirect
+	protected $noRedirect = false;	// flag for disable the redirect
+	protected $logintype;	// logintype (given as GPvar), possible: login, logout
 
 	/**
 	 * The main method of the plugin
@@ -59,10 +59,10 @@ class tx_felogin_pi1 extends tslib_pibase {
 			// Loading TypoScript array into object variable:
 		$this->conf = $conf;
 		$this->uploadDir = 'uploads/tx_felogin/';
-			
+
 			// Loading default pivars
 		$this->pi_setPiVarDefaults();
-		
+
 			// Loading language-labels
 		$this->pi_loadLL();
 
@@ -73,7 +73,11 @@ class tx_felogin_pi1 extends tslib_pibase {
 
 			// Get storage PIDs:
 		if ($this->conf['storagePid']) {
-			$this->spid = $this->conf['storagePid'];
+			if (intval($this->conf['recursive'])) {
+				$this->spid = $this->pi_getPidList($this->conf['storagePid'], intval($this->conf['recursive']));
+			} else {
+				$this->spid = $this->conf['storagePid'];
+			}
 		} else {
 			$pids = $GLOBALS['TSFE']->getStorageSiterootPids();
 			$this->spid = $pids['_STORAGE_PID'];
@@ -81,15 +85,17 @@ class tx_felogin_pi1 extends tslib_pibase {
 
 			// GPvars:
 		$this->logintype = t3lib_div::_GP('logintype');
-		$this->redirectUrl = t3lib_div::_GP('redirect_url');
+		$this->referer = t3lib_div::_GP('referer');
+		$this->noRedirect = ($this->piVars['noredirect'] || $this->conf['redirectDisable']);
 
 			// if config.typolinkLinkAccessRestrictedPages is set, the var is return_url
-		$returnUrl =  t3lib_div::_GP('return_url');  
+		$returnUrl =  t3lib_div::_GP('return_url');
 		if ($returnUrl) {
-			$this->redirectUrl = $returnUrl;	 
+			$this->redirectUrl = $returnUrl;
+		} else {
+			$this->redirectUrl = t3lib_div::_GP('redirect_url');
 		}
 
-
 			// Get Template
 		$templateFile = $this->conf['templateFile'] ? $this->conf['templateFile'] : 'EXT:felogin/template.html';
 		$this->template = $this->cObj->fileResource($templateFile);
@@ -98,15 +104,21 @@ class tx_felogin_pi1 extends tslib_pibase {
 		$this->userIsLoggedIn = $GLOBALS['TSFE']->loginUser;
 
 			// Redirect
-		if ($this->conf['redirectMode'] && !$this->conf['redirectDisable']) {
-			$this->redirectUrl = $this->processRedirect();
+		if ($this->conf['redirectMode'] && !$this->conf['redirectDisable'] && !$this->noRedirect) {
+			$redirectUrl = $this->processRedirect();
+			if (count($redirectUrl)) {
+				$this->redirectUrl = $this->conf['redirectFirstMethod'] ? array_shift($redirectUrl) : array_pop($redirectUrl);
+			} else {
+				$this->redirectUrl = '';
+		}
 		}
-
 
 			// What to display
 		$content='';
 		if ($this->piVars['forgot']) {
 			$content .= $this->showForgot();
+		} elseif ($this->piVars['forgothash']) {
+			$content .= $this->changePassword();
 		} else {
 			if($this->userIsLoggedIn && !$this->logintype) {
 				$content .= $this->showLogout();
@@ -118,12 +130,11 @@ class tx_felogin_pi1 extends tslib_pibase {
 
 
 			// Process the redirect
-		if (($this->logintype === 'login' || $this->logintype === 'logout') && $this->redirectUrl) {
+		if (($this->logintype === 'login' || $this->logintype === 'logout') && $this->redirectUrl && !$this->noRedirect) {
 			if (!$GLOBALS['TSFE']->fe_user->cookieId) {
 				$content .= '<p style="color:red; font-weight:bold;">' . $this->pi_getLL('cookie_warning', '', 1) . '</p>';
 			} else {
-				header('Location: '.t3lib_div::locationHeaderUrl($this->redirectUrl));
-				exit;
+				t3lib_utility_Http::redirect($this->redirectUrl);
 			}
 		}
 		return $this->conf['wrapContentInBaseClass'] ? $this->pi_wrapInBaseClass($content) : $content;
@@ -138,63 +149,229 @@ class tx_felogin_pi1 extends tslib_pibase {
 	 protected function showForgot() {
 		$subpart = $this->cObj->getSubpart($this->template, '###TEMPLATE_FORGOT###');
 		$subpartArray = $linkpartArray = array();
+		$postData =  t3lib_div::_POST($this->prefixId);
 
-		if ($this->piVars['forgot_email']) {
-			if (t3lib_div::validEmail($this->piVars['forgot_email'])) {
-					// look for user record and send the password
+		if ($postData['forgot_email']) {
+
+				// get hashes for compare
+			$postedHash = $postData['forgot_hash'];
+			$hashData = $GLOBALS['TSFE']->fe_user->getKey('ses', 'forgot_hash');
+
+
+			if ($postedHash === $hashData['forgot_hash']) {
+				$row = FALSE;
+
+					// look for user record
+				$data = $GLOBALS['TYPO3_DB']->fullQuoteStr($this->piVars['forgot_email'], 'fe_users');
 				$res = $GLOBALS['TYPO3_DB']->exec_SELECTquery(
-					'uid, username, password',
+					'uid, username, password, email',
 					'fe_users',
-					'email='.$GLOBALS['TYPO3_DB']->fullQuoteStr($this->piVars['forgot_email'], 'fe_users').' AND pid IN ('.$GLOBALS['TYPO3_DB']->cleanIntList($this->spid).') '.$this->cObj->enableFields('fe_users')
+					'(email=' . $data .' OR username=' . $data . ') AND pid IN ('.$GLOBALS['TYPO3_DB']->cleanIntList($this->spid).') '.$this->cObj->enableFields('fe_users')
 				);
 
 				if ($GLOBALS['TYPO3_DB']->sql_num_rows($res)) {
 					$row = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($res);
-					$msg = sprintf($this->pi_getLL('ll_forgot_email_password', '', 0), $this->piVars['forgot_email'], $row['username'], $row['password']);
+				}
+
+				if ($row) {
+							// generate an email with the hashed link
+						$error = $this->generateAndSendHash($row);
+				}
+					// generate message
+				if ($error) {
+					$markerArray['###STATUS_MESSAGE###'] = $this->cObj->stdWrap($error, $this->conf['forgotMessage_stdWrap.']);
 				} else {
-					$msg = sprintf($this->pi_getLL('ll_forgot_email_nopassword', '', 0), $this->piVars['forgot_email']);
+					$markerArray['###STATUS_MESSAGE###'] = $this->cObj->stdWrap($this->pi_getLL('ll_forgot_reset_message_emailSent', '', 1), $this->conf['forgotMessage_stdWrap.']);
 				}
-
-
-					// Generate new password with md5 and save it in user record
-				if ($GLOBALS['TYPO3_DB']->sql_num_rows($res) && t3lib_extMgm::isLoaded('kb_md5fepw')) {
-					$newPass = $this->generatePassword(8);
-					$res = $GLOBALS['TYPO3_DB']->exec_UPDATEquery(
-						'fe_users',
-						'uid=' . $row['uid'],
-						array('password' => md5($newPass))
-					);
-					$msg = sprintf($this->pi_getLL('ll_forgot_email_password', '', 0),$this->piVars['forgot_email'], $row['username'], $newPass);
-				}
-
-				$this->cObj->sendNotifyEmail($msg, $this->piVars['forgot_email'], '', $this->conf['email_from'], $this->conf['email_fromName'], $this->conf['replyTo']);
-				$markerArray['###STATUS_MESSAGE###'] = $this->cObj->stdWrap(sprintf($this->pi_getLL('ll_forgot_message_emailSent', '', 1), '<em>' . htmlspecialchars($this->piVars['forgot_email']) .'</em>'), $this->conf['forgotMessage_stdWrap.']);
 				$subpartArray['###FORGOT_FORM###'] = '';
 
 
 			} else {
 					//wrong email
-				$markerArray['###STATUS_MESSAGE###'] = $this->getDisplayText('forgot_message',$this->conf['forgotMessage_stdWrap.']);
+				$markerArray['###STATUS_MESSAGE###'] = $this->getDisplayText('forgot_reset_message', $this->conf['forgotMessage_stdWrap.']);
 				$markerArray['###BACKLINK_LOGIN###'] = '';
 			}
 		} else {
-			$markerArray['###STATUS_MESSAGE###'] = $this->getDisplayText('forgot_message',$this->conf['forgotMessage_stdWrap.']);
+			$markerArray['###STATUS_MESSAGE###'] = $this->getDisplayText('forgot_reset_message', $this->conf['forgotMessage_stdWrap.']);
 			$markerArray['###BACKLINK_LOGIN###'] = '';
 		}
 
 		$markerArray['###BACKLINK_LOGIN###'] = $this->getPageLink($this->pi_getLL('ll_forgot_header_backToLogin', '', 1), array());
-		$markerArray['###STATUS_HEADER###'] = $this->getDisplayText('forgot_header',$this->conf['forgotHeader_stdWrap.']);
+		$markerArray['###STATUS_HEADER###'] = $this->getDisplayText('forgot_header', $this->conf['forgotHeader_stdWrap.']);
 
-		$markerArray['###LEGEND###'] = $this->pi_getLL('send_password', '', 1);
-		$markerArray['###ACTION_URI###'] = $this->getPageLink('',array($this->prefixId.'[forgot]'=>1),true);
+		$markerArray['###LEGEND###'] = $this->pi_getLL('reset_password', '', 1);
+		$markerArray['###ACTION_URI###'] = $this->getPageLink('', array($this->prefixId . '[forgot]'=>1), true);
 		$markerArray['###EMAIL_LABEL###'] = $this->pi_getLL('your_email', '', 1);
 		$markerArray['###FORGOT_PASSWORD_ENTEREMAIL###'] = $this->pi_getLL('forgot_password_enterEmail', '', 1);
 		$markerArray['###FORGOT_EMAIL###'] = $this->prefixId.'[forgot_email]';
-		$markerArray['###SEND_PASSWORD###'] = $this->pi_getLL('send_password', '', 1);
+		$markerArray['###SEND_PASSWORD###'] = $this->pi_getLL('reset_password', '', 1);
+
+		$markerArray['###DATA_LABEL###'] = $this->pi_getLL('ll_enter_your_data', '', 1);
+
+
+
+		$markerArray = array_merge($markerArray, $this->getUserFieldMarkers());
+
+			// generate hash
+		$hash = md5($this->generatePassword(3));
+		$markerArray['###FORGOTHASH###'] = $hash;
+			// set hash in feuser session
+		$GLOBALS['TSFE']->fe_user->setKey('ses', 'forgot_hash', array('forgot_hash' => $hash));
+
 
 		return $this->cObj->substituteMarkerArrayCached($subpart, $markerArray, $subpartArray, $linkpartArray);
 	}
 
+	/**
+	 * This function checks the hash from link and checks the validity. If it's valid it shows the form for
+	 * changing the password and process the change of password after submit, if not valid it returns the error message
+	 *
+	 * @return	string		The content.
+	 */
+	protected function changePassword() {
+
+		$subpartArray = $linkpartArray = array();
+		$done = false;
+
+		$minLength = intval($this->conf['newPasswordMinLength']) ? intval($this->conf['newPasswordMinLength']) : 6;
+
+		$subpart = $this->cObj->getSubpart($this->template, '###TEMPLATE_CHANGEPASSWORD###');
+
+		$markerArray['###STATUS_HEADER###'] = $this->getDisplayText('change_password_header', $this->conf['changePasswordHeader_stdWrap.']);
+		$markerArray['###STATUS_MESSAGE###'] = sprintf($this->getDisplayText('change_password_message', $this->conf['changePasswordMessage_stdWrap.']), $minLength);
+
+		$markerArray['###BACKLINK_LOGIN###'] = '';
+		$uid = $this->piVars['user'];
+		$piHash = $this->piVars['forgothash'];
+
+		$hash = explode('|', $piHash);
+		if (intval($uid) == 0) {
+			$markerArray['###STATUS_MESSAGE###'] = $this->getDisplayText('change_password_notvalid_message', $this->conf['changePasswordMessage_stdWrap.']);
+			$subpartArray['###CHANGEPASSWORD_FORM###'] = '';
+		} else {
+			$user = $this->pi_getRecord('fe_users', intval($uid));
+			$userHash = $user['felogin_forgotHash'];
+			$compareHash = explode('|', $userHash);
+
+			if (!$compareHash || !$compareHash[1] || $compareHash[0] < time() ||  $hash[0] != $compareHash[0] ||  md5($hash[1]) != $compareHash[1]) {
+				$markerArray['###STATUS_MESSAGE###'] = $this->getDisplayText('change_password_notvalid_message',$this->conf['changePasswordMessage_stdWrap.']);
+				$subpartArray['###CHANGEPASSWORD_FORM###'] = '';
+			} else {
+					// all is fine, continue with new password
+				$postData = t3lib_div::_POST($this->prefixId);
+
+				if ($postData['changepasswordsubmit']) {
+					if (strlen($postData['password1']) < $minLength) {
+			 			$markerArray['###STATUS_MESSAGE###'] = sprintf($this->getDisplayText('change_password_tooshort_message', $this->conf['changePasswordMessage_stdWrap.']), $minLength);
+					} elseif ($postData['password1'] != $postData['password2']) {
+						$markerArray['###STATUS_MESSAGE###'] = sprintf($this->getDisplayText('change_password_notequal_message', $this->conf['changePasswordMessage_stdWrap.']), $minLength);
+					} else {
+						$newPass = $postData['password1'];
+
+						if ($GLOBALS['TYPO3_CONF_VARS']['EXTCONF']['felogin']['password_changed']) {
+							$_params = array(
+								'user' => $user,
+								'newPassword' => $newPass,
+							);
+							foreach($GLOBALS['TYPO3_CONF_VARS']['EXTCONF']['felogin']['password_changed'] as $_funcRef) {
+								if ($_funcRef) {
+									t3lib_div::callUserFunction($_funcRef, $_params, $this);
+								}
+							}
+							$newPass = $_params['newPassword'];
+						}
+
+							// save new password and clear DB-hash
+						$res = $GLOBALS['TYPO3_DB']->exec_UPDATEquery(
+								'fe_users',
+								'uid=' . $user['uid'],
+								array('password' => $newPass, 'felogin_forgotHash' => '')
+							);
+						$markerArray['###STATUS_MESSAGE###'] = $this->getDisplayText('change_password_done_message', $this->conf['changePasswordMessage_stdWrap.']);
+						$done = true;
+						$subpartArray['###CHANGEPASSWORD_FORM###'] = '';
+						$markerArray['###BACKLINK_LOGIN###'] = $this->getPageLink($this->pi_getLL('ll_forgot_header_backToLogin', '', 1), array());
+					}
+				}
+
+				if (!$done) {
+					// Change password form
+					$markerArray['###ACTION_URI###'] = $this->pi_getPageLink($GLOBALS['TSFE']->id, '', array(
+						$this->prefixId . '[user]' => $user['uid'],
+						$this->prefixId . '[forgothash]' => $piHash
+					));
+					$markerArray['###LEGEND###'] = $this->pi_getLL('change_password', '', 1);
+					$markerArray['###NEWPASSWORD1_LABEL###'] = $this->pi_getLL('newpassword_label1', '', 1);
+					$markerArray['###NEWPASSWORD2_LABEL###'] = $this->pi_getLL('newpassword_label2', '', 1);
+					$markerArray['###NEWPASSWORD1###'] = $this->prefixId . '[password1]';
+					$markerArray['###NEWPASSWORD2###'] = $this->prefixId . '[password2]';
+					$markerArray['###STORAGE_PID###'] = $this->spid;
+					$markerArray['###SEND_PASSWORD###'] = $this->pi_getLL('change_password', '', 1);
+					$markerArray['###FORGOTHASH###'] = $piHash;
+				}
+			}
+		}
+
+		return $this->cObj->substituteMarkerArrayCached($subpart, $markerArray, $subpartArray, $linkpartArray);
+	}
+
+	/**
+	 * generates a hashed link and send it with email
+	 *
+	 * @param	array		$user   contains user data
+	 * @return	string		Empty string with success, error message with no success
+	 */
+	protected function generateAndSendHash($user) {
+		$hours = intval($this->conf['forgotLinkHashValidTime']) > 0 ? intval($this->conf['forgotLinkHashValidTime']) : 24;
+		$validEnd = time() + 3600 * $hours;
+		$validEndString = date($this->conf['dateFormat'], $validEnd);
+
+		$hash =  md5(rand());
+		$randHash = $validEnd . '|' . $hash;
+		$randHashDB = $validEnd . '|' . md5($hash);
+
+		//write hash to DB
+		$res = $GLOBALS['TYPO3_DB']->exec_UPDATEquery('fe_users', 'uid=' . $user['uid'], array('felogin_forgotHash' => $randHashDB));
+
+		// send hashlink to user
+		$this->conf['linkPrefix'] = -1;
+		$isAbsRelPrefix = !empty($GLOBALS['TSFE']->absRefPrefix);
+		$isBaseURL  = !empty($GLOBALS['TSFE']->baseUrl);
+		$isFeloginBaseURL = !empty($this->conf['feloginBaseURL']);
+
+		if ($isFeloginBaseURL) {
+				// first priority
+			$this->conf['linkPrefix'] = $this->conf['feloginBaseURL'];
+		} else {
+			if ($isBaseURL) {
+					// 3rd priority
+				$this->conf['linkPrefix'] = $GLOBALS['TSFE']->baseUrl;
+			}
+		}
+
+		if ($this->conf['linkPrefix'] == -1 && !$isAbsRelPrefix) {
+				// no preix is set, return the error
+			return $this->pi_getLL('ll_change_password_nolinkprefix_message');
+		}
+
+		$link = ($isAbsRelPrefix ? '' : $this->conf['linkPrefix']) . $this->pi_getPageLink($GLOBALS['TSFE']->id, '', array(
+			$this->prefixId . '[user]' => $user['uid'],
+			$this->prefixId . '[forgothash]' => $randHash
+		));
+
+		$msg = sprintf($this->pi_getLL('ll_forgot_validate_reset_password', '', 0), $user['username'], $link, $validEndString);
+
+			// no RDCT - Links for security reasons
+		$oldSetting = $GLOBALS['TSFE']->config['config']['notification_email_urlmode'];
+		$GLOBALS['TSFE']->config['config']['notification_email_urlmode'] = 0;
+			// send the email
+		$this->cObj->sendNotifyEmail($msg, $user['email'], '', $this->conf['email_from'], $this->conf['email_fromName'], $this->conf['replyTo']);
+			// restore settings
+		$GLOBALS['TSFE']->config['config']['notification_email_urlmode'] = $oldSetting;
+
+		return '';
+	}
+
 	/**
 	 * Shows logout form
 	 *
@@ -214,6 +391,9 @@ class tx_felogin_pi1 extends tslib_pibase {
 		$markerArray['###STORAGE_PID###'] = $this->spid;
 		$markerArray['###USERNAME###'] = htmlspecialchars($GLOBALS['TSFE']->fe_user->user['username']);
 		$markerArray['###USERNAME_LABEL###'] = $this->pi_getLL('username', '', 1);
+		$markerArray['###NOREDIRECT###'] = $this->noRedirect ? '1' : '0';
+		$markerArray['###PREFIXID###'] = $this->prefixId;
+		$markerArray = array_merge($markerArray, $this->getUserFieldMarkers());
 
 		if ($this->redirectUrl) {
 				// use redirectUrl for action tag because of possible access restricted pages
@@ -232,7 +412,7 @@ class tx_felogin_pi1 extends tslib_pibase {
 		$subpart = $this->cObj->getSubpart($this->template, '###TEMPLATE_LOGIN###');
 		$subpartArray = $linkpartArray = array();
 
-		$gpRedirectUrl = ''; 
+		$gpRedirectUrl = '';
 
 		$markerArray['###LEGEND###'] = $this->pi_getLL('oLabel_header_welcome', '', 1);
 
@@ -240,7 +420,8 @@ class tx_felogin_pi1 extends tslib_pibase {
 			if($this->userIsLoggedIn) {
 					// login success
 				$markerArray['###STATUS_HEADER###'] = $this->getDisplayText('success_header',$this->conf['successHeader_stdWrap.']);
-				$markerArray['###STATUS_MESSAGE###'] = str_replace('###USER###',htmlspecialchars($GLOBALS['TSFE']->fe_user->user['username']),$this->getDisplayText('success_message',$this->conf['successMessage_stdWrap.']));
+				$markerArray['###STATUS_MESSAGE###'] = $this->getDisplayText('success_message', $this->conf['successMessage_stdWrap.']);
+				$markerArray = array_merge($markerArray, $this->getUserFieldMarkers());
 				$subpartArray['###LOGIN_FORM###'] = '';
 
 					// Hook for general actions after after login has been confirmed (by Thomas Danzl <thomas@danzl.org>)
@@ -277,10 +458,19 @@ class tx_felogin_pi1 extends tslib_pibase {
 			// The methods should also set the required JS functions to get included
 		$onSubmit = '';
 		$extraHidden = '';
+		$onSubmitAr = array();
+		$extraHiddenAr = array();
+
+	 		// check for referer redirect method. if present, save referer in form field
+		if (t3lib_div::inList($this->conf['redirectMode'], 'referer') || t3lib_div::inList($this->conf['redirectMode'], 'refererDomains')) {
+			$referer = $this->referer ? $this->referer : t3lib_div::getIndpEnv('HTTP_REFERER');
+			if ($referer) {
+				$extraHiddenAr[] = '<input type="hidden" name="referer" value="' . rawurlencode($referer) . '" />';
+			}
+		}
+
 		if (is_array($GLOBALS['TYPO3_CONF_VARS']['EXTCONF']['felogin']['loginFormOnSubmitFuncs'])) {
 			$_params = array();
-			$onSubmitAr = array();
-			$extraHiddenAr = array();
 			foreach($GLOBALS['TYPO3_CONF_VARS']['EXTCONF']['felogin']['loginFormOnSubmitFuncs'] as $funcRef) {
 				list($onSub, $hid) = t3lib_div::callUserFunction($funcRef, $_params, $this);
 				$onSubmitAr[] = $onSub;
@@ -289,9 +479,15 @@ class tx_felogin_pi1 extends tslib_pibase {
 		}
 		if (count($onSubmitAr)) {
 			$onSubmit = implode('; ', $onSubmitAr).'; return true;';
+		}
+		if (count($extraHiddenAr)) {
 			$extraHidden = implode(chr(10), $extraHiddenAr);
 		}
 
+		if (!$gpRedirectUrl && $this->redirectUrl && $this->logintype === 'login') {
+			$gpRedirectUrl = $this->redirectUrl;
+		}
+
 			// Login form
 		$markerArray['###ACTION_URI###'] = $this->getPageLink('',array(),true);
 		$markerArray['###EXTRA_HIDDEN###'] = $extraHidden; // used by kb_md5fepw extension...
@@ -301,7 +497,10 @@ class tx_felogin_pi1 extends tslib_pibase {
 		$markerArray['###PASSWORD_LABEL###'] = $this->pi_getLL('password', '', 1);
 		$markerArray['###STORAGE_PID###'] = $this->spid;
 		$markerArray['###USERNAME_LABEL###'] = $this->pi_getLL('username', '', 1);
-		$markerArray['###REDIRECT_URL###'] = $gpRedirectUrl ? htmlspecialchars($gpRedirectUrl) : htmlspecialchars($this->redirectUrl);
+		$markerArray['###REDIRECT_URL###'] = htmlspecialchars($gpRedirectUrl);
+		$markerArray['###NOREDIRECT###'] = $this->noRedirect ? '1' : '0';
+		$markerArray['###PREFIXID###'] = $this->prefixId;
+		$markerArray = array_merge($markerArray, $this->getUserFieldMarkers());
 
 		if ($this->flexFormValue('showForgotPassword','sDEF') || $this->conf['showForgotPasswordLink']) {
 			$linkpartArray['###FORGOT_PASSWORD_LINK###'] = explode('|',$this->getPageLink('|',array($this->prefixId.'[forgot]'=>1)));
@@ -311,8 +510,8 @@ class tx_felogin_pi1 extends tslib_pibase {
 		}
 
 
-
-		if (($this->conf['showPermaLogin']) && ($GLOBALS['TYPO3_CONF_VARS']['FE']['permalogin'] == 0 || $GLOBALS['TYPO3_CONF_VARS']['FE']['permalogin'] == 1) && $GLOBALS['TYPO3_CONF_VARS']['FE']['lifetime'] > 0) {
+			// Permanent Login is only possible if permalogin is not deactivated (-1) and lifetime is greater than 0
+		if ($this->conf['showPermaLogin'] && t3lib_div::inList('0,1,2', $GLOBALS['TYPO3_CONF_VARS']['FE']['permalogin']) && $GLOBALS['TYPO3_CONF_VARS']['FE']['lifetime'] > 0) {
 			$markerArray['###PERMALOGIN###'] = $this->pi_getLL('permalogin', '', 1);
 			if($GLOBALS['TYPO3_CONF_VARS']['FE']['permalogin'] == 1) {
 				$markerArray['###PERMALOGIN_HIDDENFIELD_ATTRIBUTES###'] = 'disabled="disabled"';
@@ -333,8 +532,10 @@ class tx_felogin_pi1 extends tslib_pibase {
 	 * @return	string		redirect url
 	 */
 	 protected function processRedirect() {
+	 	$redirect_url = array();
 		if ($this->conf['redirectMode']) {
-			foreach (t3lib_div::trimExplode(',', $this->conf['redirectMode'],1) as $redirMethod) {
+			$redirectMethods = t3lib_div::trimExplode(',', $this->conf['redirectMode'], TRUE);
+			foreach ($redirectMethods as $redirMethod) {
 				if ($GLOBALS['TSFE']->loginUser && $this->logintype === 'login') {
 						// logintype is needed because the login-page wouldn't be accessible anymore after a login (would always redirect)
 					switch ($redirMethod) {
@@ -343,10 +544,10 @@ class tx_felogin_pi1 extends tslib_pibase {
 							$res = $GLOBALS['TYPO3_DB']->exec_SELECTquery(
 								'felogin_redirectPid',
 								$GLOBALS['TSFE']->fe_user->usergroup_table,
-								'felogin_redirectPid!="" AND uid IN ('.implode(',',$groupData['uid']).')'
+								'felogin_redirectPid!="" AND uid IN (' . implode(',', $groupData['uid']) . ')'
 							);
 							if ($row = $GLOBALS['TYPO3_DB']->sql_fetch_row($res))	{
-								$redirect_url = $this->pi_getPageLink($row[0],array(),true); // take the first group with a redirect page
+								$redirect_url[] = $this->pi_getPageLink($row[0], array(), TRUE); // take the first group with a redirect page
 							}
 						break;
 						case 'userLogin':
@@ -356,47 +557,48 @@ class tx_felogin_pi1 extends tslib_pibase {
 								$GLOBALS['TSFE']->fe_user->userid_column . '=' . $GLOBALS['TSFE']->fe_user->user['uid'] . ' AND felogin_redirectPid!=""'
 							);
 							if ($row = $GLOBALS['TYPO3_DB']->sql_fetch_row($res))	{
-								$redirect_url = $this->pi_getPageLink($row[0],array(),true);
+								$redirect_url[] = $this->pi_getPageLink($row[0], array(), TRUE);
 							}
 						break;
 						case 'login':
 							if ($this->conf['redirectPageLogin']) {
-								$redirect_url = $this->pi_getPageLink(intval($this->conf['redirectPageLogin']),array(),true);
+								$redirect_url[] = $this->pi_getPageLink(intval($this->conf['redirectPageLogin']), array(), TRUE);
 							}
 						break;
 						case 'getpost':
-							$redirect_url = $this->redirectUrl;
+							$redirect_url[] = $this->redirectUrl;
 						break;
 						case 'referer':
-							$redirect_url = t3lib_div::getIndpEnv('HTTP_REFERER');
 								// avoid forced logout, when trying to login immediatly after a logout
-							$redirect_url = ereg_replace("[&?]logintype=[a-z]+", '', $redirect_url);
+							$redirect_url[] = preg_replace('/[&?]logintype=[a-z]+/', '', $this->referer);
 						break;
 						case 'refererDomains':
 								// Auto redirect.
 								// Feature to redirect to the page where the user came from (HTTP_REFERER).
 								// Allowed domains to redirect to, can be configured with plugin.tx_felogin_pi1.domains
 								// Thanks to plan2.net / Martin Kutschker for implementing this feature.
-							if (!$redirect_url && $this->conf['domains']) {
-								$redirect_url = t3lib_div::getIndpEnv('HTTP_REFERER');
+							if ($this->conf['domains']) {
+								$url = $this->referer;
 									// is referring url allowed to redirect?
 								$match = array();
-								if (ereg('^http://([[:alnum:]._-]+)/', $redirect_url, $match)) {
+								if (preg_match('/^http://([[:alnum:]._-]+)//', $url, $match)) {
 									$redirect_domain = $match[1];
 									$found = false;
 									foreach(split(',', $this->conf['domains']) as $d) {
-										if (ereg('(^|\.)'.$d.'$', $redirect_domain)) {
+										if (preg_match('/(^|\.)/'.$d.'$', $redirect_domain)) {
 											$found = true;
 											break;
 										}
 									}
 									if (!$found) {
-										$redirect_url = '';
+										$url = '';
 									}
 								}
 
 									// Avoid forced logout, when trying to login immediatly after a logout
-								$redirect_url = ereg_replace("[&?]logintype=[a-z]+", "", $redirect_url);
+								if ($url) {
+									$redirect_url[] = preg_replace('/[&?]logintype=[a-z]+/', '', $url);
+							}
 							}
 						break;
 					}
@@ -404,10 +606,22 @@ class tx_felogin_pi1 extends tslib_pibase {
 					switch ($redirMethod) {
 						case 'loginError':
 							if ($this->conf['redirectPageLoginError']) {
-								$redirect_url = $this->pi_getPageLink(intval($this->conf['redirectPageLoginError']), array(), true);
+								$redirect_url[] = $this->pi_getPageLink(intval($this->conf['redirectPageLoginError']), array(), TRUE);
 							}
 						break;
 					}
+				} elseif (($this->logintype == '') && ($redirMethod == 'login') && $this->conf['redirectPageLogin']) {
+						// if login and page not accessible
+					$this->cObj->typolink('', array(
+						'parameter' 				=> $this->conf['redirectPageLogin'],
+						'linkAccessRestrictedPages' => TRUE,
+					));
+					$redirect_url[] = $this->cObj->lastTypoLinkUrl;
+
+				} elseif (($this->logintype == '') && ($redirMethod == 'logout') && $this->conf['redirectPageLogout'] && $GLOBALS['TSFE']->loginUser) {
+						// if logout and page not accessible
+					$redirect_url[] = $this->pi_getPageLink(intval($this->conf['redirectPageLogout']), array(), TRUE);
+
 				} elseif ($this->logintype === 'logout') { // after logout
 
 					// Hook for general actions after after logout has been confirmed
@@ -423,7 +637,7 @@ class tx_felogin_pi1 extends tslib_pibase {
 					switch ($redirMethod) {
 						case 'logout':
 							if ($this->conf['redirectPageLogout']) {
-								$redirect_url = $this->pi_getPageLink(intval($this->conf['redirectPageLogout']), array(), true);
+								$redirect_url[] = $this->pi_getPageLink(intval($this->conf['redirectPageLogout']), array(), TRUE);
 							}
 						break;
 					}
@@ -432,17 +646,19 @@ class tx_felogin_pi1 extends tslib_pibase {
 					switch ($redirMethod) {
 						case 'getpost':
 							// preserve the get/post value
-							$redirect_url = $this->redirectUrl;
+							$redirect_url[] = $this->redirectUrl;
 						break;
 					}
 				}
 
-				if ($redirect_url && $this->conf['redirectFirstMethod']) {
-					break;
 				}
 			}
+				// remove empty values
+			if (count($redirect_url)) {
+				return t3lib_div::trimExplode(',', implode(',', $redirect_url), TRUE);
+			} else {
+				return array();
 		}
-		return $redirect_url;
 	}
 
 	/**
@@ -465,7 +681,7 @@ class tx_felogin_pi1 extends tslib_pibase {
 		}
 
 		if ($this->flexFormValue('recursive', 'sDEF')) {
-			$flex['recursive'] = $this->flexFormValue('recursive',	'sDEF');
+			$flex['recursive'] = $this->flexFormValue('recursive', 'sDEF');
 		}
 
 		if ($this->flexFormValue('templateFile', 'sDEF')) {
@@ -543,7 +759,7 @@ class tx_felogin_pi1 extends tslib_pibase {
 		}
 
 		if ($returnUrl) {
-			return $this->cObj->typolink_url($this->conf['linkConfig.']);
+			return htmlspecialchars($this->cObj->typolink_url($this->conf['linkConfig.']));
 		} else {
 			return $this->cObj->typolink($label,$this->conf['linkConfig.']);
 		}
@@ -562,17 +778,17 @@ class tx_felogin_pi1 extends tslib_pibase {
 		$preserveVars =! ($this->conf['preserveGETvars'] || $this->conf['preserveGETvars']=='all' ? array() : implode(',', (array)$this->conf['preserveGETvars']));
 		$getVars = t3lib_div::_GET();
 
-		foreach ($getVars as $key=>$val) {
+		foreach ($getVars as $key => $val) {
 			if (stristr($key,$this->prefixId) === false) {
 				if (is_array($val)) {
-					foreach ($val as $key1=>$val1) {
-						if ($this->conf['preserveGETvars']=='all' || in_array($key.'['.$key1.']',$preserveVars)) {
-							$params.='&'.$key.'['.$key1.']='.$val1;
+					foreach ($val as $key1 => $val1) {
+						if ($this->conf['preserveGETvars'] == 'all' || in_array($key . '[' . $key1 .']', $preserveVars)) {
+							$params .= '&' . $key . '[' . $key1 . ']=' . $val1;
 						}
 					}
 				} else {
-					if (!in_array($key,array('id','no_cache','logintype','redirect_url','cHash'))) {
-						$params.='&'.$key.'='.$val;
+					if (!in_array($key, array('id','no_cache','logintype','redirect_url','cHash'))) {
+						$params .= '&' . $key . '=' . $val;
 					}
 				}
 			}
@@ -593,9 +809,9 @@ class tx_felogin_pi1 extends tslib_pibase {
 		while ($len--) {
 			$char = rand(0,35);
 			if ($char < 10) {
-				$pass .= ''.$char;
+				$pass .= '' . $char;
 			} else {
-				$pass .= chr($char-10+97);
+				$pass .= chr($char - 10 + 97);
 			}
 		}
 		return $pass;
@@ -609,7 +825,28 @@ class tx_felogin_pi1 extends tslib_pibase {
 	 * @return	string		label text
 	 */
 	protected function getDisplayText($label, $stdWrapArray=array()) {
-		return $this->flexFormValue($label,'s_messages') ? $this->cObj->stdWrap($this->flexFormValue($label,'s_messages'),$stdWrapArray) : $this->cObj->stdWrap($this->pi_getLL('ll_'.$label, '', 1), $stdWrapArray);
+		$text = $this->flexFormValue($label, 's_messages') ? $this->cObj->stdWrap($this->flexFormValue($label, 's_messages'), $stdWrapArray) : $this->cObj->stdWrap($this->pi_getLL('ll_'.$label, '', 1), $stdWrapArray);
+		$replace = $this->getUserFieldMarkers();
+		return strtr($text, $replace);
+	}
+
+	/**
+	 * Returns Array of markers filled with user fields
+	 *
+	 * @return	array		marker array
+	 */
+	protected function getUserFieldMarkers() {
+		$marker = array();
+		// replace markers with fe_user data
+		if ($GLOBALS['TSFE']->fe_user->user) {
+			// all fields of fe_user will be replaced, scheme is ###FEUSER_FIELDNAME###
+			foreach ($GLOBALS['TSFE']->fe_user->user as $field => $value) {
+				$marker['###FEUSER_' . t3lib_div::strtoupper($field) . '###'] = $this->cObj->stdWrap($value, $this->conf['userfields.'][$field . '.']);
+			}
+			// add ###USER### for compatibility
+			$marker['###USER###'] = $marker['###FEUSER_USERNAME###'];
+		}
+		return $marker;
 	}
 }
 
@@ -619,4 +856,4 @@ if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/felogin
 	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/felogin/pi1/class.tx_felogin_pi1.php']);
 }
 
-?>
+?>
\ No newline at end of file
