@@ -700,18 +700,15 @@ class tx_indexedsearch_crawler {
 
 			// Indexing the record as a page (but with parameters set, see ->backend_setFreeIndexUid())
 		$indexerObj->backend_indexAsTYPO3Page(
-			strip_tags($theTitle),
+			strip_tags(str_replace('<', ' <', $theTitle)),
 			'',
 			'',
-			strip_tags($theContent),
+			strip_tags(str_replace('<', ' <', $theContent)),
 			$GLOBALS['LANG']->charSet,	// Requires that
 			$r[$GLOBALS['TCA'][$cfgRec['table2index']]['ctrl']['tstamp']],
 			$r[$GLOBALS['TCA'][$cfgRec['table2index']]['ctrl']['crdate']],
 			$r['uid']
 		);
-
-		#echo print_r($indexerObj->internal_log);
-		#echo print_r($indexerObj->contentParts);
 	}
 
 	/**
