@@ -29,7 +29,7 @@
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/
 /*
- * TYPO3 SVN ID: $Id: htmlarea-gecko.js 6962 2010-02-22 00:46:26Z stan $
+ * TYPO3 SVN ID: $Id: htmlarea-gecko.js 7020 2010-02-23 14:34:10Z stan $
  */
 
 /***************************************************
@@ -743,10 +743,9 @@ HTMLArea.prototype._detectURL = function(ev) {
 			var a = textNode.parentNode.insertBefore(tag, rightText);
 			HTMLArea.removeFromParent(textNode);
 			a.appendChild(textNode);
-			rightText.data += " ";
-			s.collapse(rightText, rightText.data.length);
-			HTMLArea._stopEvent(ev);
-	
+			s.collapse(rightText, 0);
+			rightText.parentNode.normalize();
+
 			editor._unLink = function() {
 				var t = a.firstChild;
 				a.removeChild(t);
