@@ -2,10 +2,10 @@
 /***************************************************************
 *  Copyright notice
 *
-*  (c) 2005-2008 Stanislas Rolland <typo3(arobas)sjbr.ca>
+*  (c) 2005-2009 Stanislas Rolland <typo3(arobas)sjbr.ca>
 *  All rights reserved
 *
-*  This script is part of the TYPO3 project. The TYPO3 project is 
+*  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
@@ -13,7 +13,7 @@
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
-*  A copy is found in the textfile GPL.txt and important notices to the license 
+*  A copy is found in the textfile GPL.txt and important notices to the license
 *  from the author is found in LICENSE.txt distributed with these scripts.
 *
 *
@@ -24,12 +24,12 @@
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/
-/** 
+/**
  * Acronym content for htmlArea RTE
  *
  * @author	Stanislas Rolland <typo3(arobas)sjbr.ca>
  *
- * $Id: class.tx_rtehtmlarea_acronym_mod.php 4145 2008-09-18 19:11:04Z stan $  *
+ * $Id: class.tx_rtehtmlarea_acronym_mod.php 5557 2009-06-05 07:45:33Z patrick $  *
  */
 
 class tx_rtehtmlarea_acronym_mod {
@@ -48,41 +48,26 @@ class tx_rtehtmlarea_acronym_mod {
 	 */
 	function init()	{
 		global $BE_USER,$LANG,$BACK_PATH;
-		
+
 		$this->doc = t3lib_div::makeInstance('template');
-		$this->doc->docType = 'xhtml_trans';
 		$this->doc->backPath = $BACK_PATH;
 		$this->doc->styleSheetFile = "";
 		$this->doc->styleSheetFile_post = "";
 		$this->doc->bodyTagAdditions = 'class="popupwin" onload="init();"';
-		$this->doc->form = '<form action="" id="content" name="content" method="POST">';
+		$this->doc->form = '<form action="" id="content" name="content" method="post">';
 		$JScode='
 			var dialog = window.opener.HTMLArea.Dialog.Acronym;
+			var plugin = dialog.plugin;
 			var editor = dialog.plugin.editor;
-			var param = null;
-			var html = editor.getSelectedHTML();
-			var sel = editor._getSelection();
-			var range = editor._createRange(sel);
-			var abbr = editor._activeElement(sel);
-				// Working around Safari issue
-			if (!abbr && editor._statusBarTree.selected) {
-				abbr = editor._statusBarTree.selected;
-			}
-			var abbrType = null;
-			var acronyms = new Object();
-			var abbreviations = new Object();
-			if (!(abbr != null && /^(acronym|abbr)$/i.test(abbr.nodeName))) {
-				abbr = editor._getFirstAncestor(sel, ["acronym", "abbr"]);
-			}
-			if (abbr != null && /^(acronym|abbr)$/i.test(abbr.nodeName)) {
-				param = { title : abbr.title, text : abbr.innerHTML};
-				abbrType = abbr.nodeName.toLowerCase();
-			} else {
-				param = { title : "", text : html};
-			}
-			
+			var param = dialog.plugin.param,
+				abbr = dialog.plugin.abbr,
+				abbrType = dialog.plugin.abbrType,
+				html = "",
+				acronyms = new Object(),
+				abbreviations = new Object();
+
 			function setType() {
-				if(document.content.acronym.checked) {
+				if (document.content.acronym.checked) {
 					abbrType = "acronym";
 					document.getElementById("abbrType").innerHTML = "' . $LANG->getLL('Acronym') . '";
 				} else {
@@ -90,10 +75,11 @@ class tx_rtehtmlarea_acronym_mod {
 					document.getElementById("abbrType").innerHTML = "' . $LANG->getLL('Abbreviation') . '";
 				}
 				document.getElementById("title").value = param["title"];
+				rtehtmlareaAcronymFillLanguage();
 				fillSelect(param);
 				dialog.resize();
 			}
-			
+
 			function init() {
 				dialog.initialize("noLocalize", "noResize");
 				var abbrData = dialog.plugin.getJavascriptFile(dialog.plugin.acronymUrl, "noEval");
@@ -115,7 +101,7 @@ class tx_rtehtmlarea_acronym_mod {
 				HTMLArea._addEvents(document.content.title,["keypress", "keydown", "dragdrop", "drop", "paste", "change"],function(ev) { document.content.termSelector.selectedIndex=-1; document.content.acronymSelector.selectedIndex=-1; });
 				document.getElementById("title").focus();
 			};
-			
+
 			function fillSelect(param) {
 				var termSelector = document.getElementById("termSelector");
 				var acronymSelector = document.getElementById("acronymSelector");
@@ -133,19 +119,26 @@ class tx_rtehtmlarea_acronym_mod {
 				if (abbrObj != "") {
 					var sameTerm = false;
 					var sameAbbreviation = false;
+					var selectedOption = false;
 					for (var i in abbrObj) {
-						if (param["title"]) {
-							sameTerm = (param["title"] == i);
-						} else {
-							sameTerm = (param["text"] == i);
-						}
-						sameAbbreviation = (param["text"] == abbrObj[i]);
-						if (!param["text"] || sameTerm || sameAbbreviation) {
-							termSelector.options[termSelector.options.length] = new Option(i, i, false, sameTerm);
-							acronymSelector.options[acronymSelector.options.length] = new Option(abbrObj[i], abbrObj[i], false, sameTerm);
-						}
-						if (sameTerm) {
-							document.content.title.value = i;
+						if (abbrObj.hasOwnProperty(i)) {
+							if (param["title"]) {
+								sameTerm = (param["title"] == i);
+							} else {
+								sameTerm = (param["text"] == i);
+							}
+							sameAbbreviation = (param["text"] == abbrObj[i]);
+							if (!selectedOption && (sameTerm || sameAbbreviation)) {
+								selectedOption = i;
+							}
+							if (!param["text"] || sameTerm || sameAbbreviation) {
+								termSelector.options[termSelector.options.length] = new Option(i, i, false, (selectedOption == i));
+								acronymSelector.options[acronymSelector.options.length] = new Option(abbrObj[i], abbrObj[i], false, (selectedOption == i));
+							}
+							if (selectedOption == i) {
+								document.content.title.value = i;
+								rtehtmlareaAcronymSelectedLanguage(i);
+							}
 						}
 					}
 				}
@@ -155,7 +148,7 @@ class tx_rtehtmlarea_acronym_mod {
 					document.getElementById("selector").style.display = "block";
 				}
 			};
-			
+
 			function processAcronym(title) {
 				if (title == "" || title == null) {
 					if (abbr) {
@@ -163,6 +156,11 @@ class tx_rtehtmlarea_acronym_mod {
 					}
 				} else {
 					var doc = editor._doc;
+					var languageObject = plugin.getPluginInstance("Language");
+					if (plugin.isButtonInToolbar("Language")) {
+						var select = document.getElementById("termLanguageSelector");
+						var language = select.options[select.selectedIndex].value;
+					}
 					if (!abbr) {
 						abbr = doc.createElement(abbrType);
 						abbr.title = title;
@@ -170,21 +168,74 @@ class tx_rtehtmlarea_acronym_mod {
 							html = document.content.acronymSelector.options[document.content.acronymSelector.selectedIndex].value;
 						}
 						abbr.innerHTML = html;
-						if (HTMLArea.is_ie) range.pasteHTML(abbr.outerHTML);
-							else editor.insertNodeAtSelection(abbr);
+						if (languageObject && plugin.isButtonInToolbar("Language")) {
+							languageObject.setLanguageAttributes(abbr, language);
+						}
+						editor.insertNodeAtSelection(abbr);
 					} else {
 						abbr.title = title;
-						if(document.content.acronymSelector.options.length != 1 && document.content.termSelector.selectedIndex > 0 && document.content.termSelector.options[document.content.termSelector.selectedIndex].value == title) abbr.innerHTML = document.content.acronymSelector.options[document.content.acronymSelector.selectedIndex].value;
+						if (languageObject && plugin.isButtonInToolbar("Language")) {
+							languageObject.setLanguageAttributes(abbr, language);
+						}
+						if (document.content.acronymSelector.options.length != 1 && document.content.termSelector.selectedIndex > 0 && document.content.termSelector.options[document.content.termSelector.selectedIndex].value == title) {
+							abbr.innerHTML = document.content.acronymSelector.options[document.content.acronymSelector.selectedIndex].value;
+						}
 					}
 				}
 			};
-			
+
+			function rtehtmlareaAcronymFillLanguage() {
+				if (plugin.isButtonInToolbar("Language")) {
+					var languageOptions = plugin.getDropDownConfiguration("Language").options;
+					var select = document.getElementById("termLanguageSelector");
+					while (select.options.length > 0) {
+						select.options[select.length-1] = null;
+					}
+					for (var option in languageOptions) {
+						if (languageOptions.hasOwnProperty(option)) {
+							var addOption = document.createElement("option");
+							addOption.innerHTML = option;
+							addOption.value = languageOptions[option];
+							select.appendChild(addOption);
+						}
+					}
+				} else {
+					document.getElementById("languageSelector").style.display = "none";
+				}
+			};
+
+			function rtehtmlareaAcronymSelectedLanguage(term) {
+				if (abbrType == "acronym") {
+					var languages = acronymLanguage;
+				} else {
+					var languages = abbreviationLanguage;
+				}
+				if (document.getElementById("languageSelector").style.display != "none") {
+					var select = document.getElementById("termLanguageSelector");
+					var options = select.options;
+					for (var i = options.length; --i >= 0;) {
+						options[i].selected = false;
+					}
+					select.selectedIndex = 0;
+					options[0].selected = true;
+					if (languages[term]) {
+						for (i = options.length; --i >= 0;) {
+							if (languages[term] == options[i].value) {
+								options[i].selected = true;
+								select.selectedIndex = i;
+								break;
+							}
+						}
+					}
+				}
+			}
+
 			function onOK() {
 				processAcronym(document.getElementById("title").value);
 				dialog.close();
 				return false;
 			};
-			
+
 			function onDelete() {
 				processAcronym("");
 				dialog.close();
@@ -195,36 +246,36 @@ class tx_rtehtmlarea_acronym_mod {
 				return false;
 			};
 		';
-		
+
 		$this->doc->JScode .= $this->doc->wrapScriptTags($JScode);
-		
+
 		$this->modData = $BE_USER->getModuleData('acronym.php','ses');
 		$BE_USER->pushModuleData('acronym.php',$this->modData);
 	}
-	
+
 	/**
 	 * [Describe function...]
-	 * 
+	 *
 	 * @return	[type]		...
 	 */
 	function main()	{
-		
+
 		$this->content='';
 		$this->content.=$this->main_acronym($this->modData['openKeys']);
 	}
-	
+
 	/**
 	 * [Describe function...]
-	 * 
+	 *
 	 * @return	[type]		...
 	 */
 	function printContent()	{
 		echo $this->content;
 	}
-	
+
 	/**
 	 * Rich Text Editor (RTE) acronym selector
-	 * 
+	 *
 	 * @param	[type]		$openKeys: ...
 	 * @return	[type]		...
 	 */
@@ -232,11 +283,11 @@ class tx_rtehtmlarea_acronym_mod {
 		global $LANG, $BE_USER;
 
 		$content.=$this->doc->startPage($LANG->getLL('Insert/Modify Acronym',1));
-		
+
 		$RTEtsConfigParts = explode(':',t3lib_div::_GP('RTEtsConfigParams'));
 		$RTEsetup = $BE_USER->getTSConfig('RTE',t3lib_BEfunc::getPagesTSconfig($RTEtsConfigParts[5]));
 		$thisConfig = t3lib_BEfunc::RTEsetup($RTEsetup['properties'],$RTEtsConfigParts[0],$RTEtsConfigParts[2],$RTEtsConfigParts[4]);
-		
+
 		$content.='
 	<div class="title" id="abbrType">' . $LANG->getLL('Acronym',1) . '</div>
 	<fieldset id="type">
@@ -246,16 +297,29 @@ class tx_rtehtmlarea_acronym_mod {
 	</fieldset>
 	<fieldset id="selector">
 		<legend>' . $LANG->getLL('Defined_term',1) . '</legend>
-		<label for="termSelector" class="fl" id="termSelectorLabel" title="' . $LANG->getLL('Select_a_term',1) . '">' . $LANG->getLL('Unabridged_term',1) . '</label>
-		<select id="termSelector" name="termSelector"  title="' . $LANG->getLL('Select_a_term',1) . '"
-			onChange="document.content.acronymSelector.selectedIndex=document.content.termSelector.selectedIndex; document.content.title.value=document.content.termSelector.options[document.content.termSelector.selectedIndex].value;">
-			<option value=""></option>
-		</select>
-		<label for="acronymSelector" id="acronymSelectorLabel" title="' . $LANG->getLL('Select_an_acronym',1) . '">' . $LANG->getLL('Abridged_term',1) . '</label>
-		<select id="acronymSelector" name="acronymSelector"  title="' . $LANG->getLL('Select_an_acronym',1) . '"
-			onChange="document.content.termSelector.selectedIndex=document.content.acronymSelector.selectedIndex; document.content.title.value=document.content.termSelector.options[document.content.termSelector.selectedIndex].value;">
-			<option value=""></option>
-		</select>
+		<div>
+			<label class="fl" for="termSelector" id="termSelectorLabel" title="' . $LANG->getLL('Select_a_term',1) . '">' . $LANG->getLL('Unabridged_term',1) . '</label>
+			<select id="termSelector" name="termSelector"  title="' . $LANG->getLL('Select_a_term',1) . '"
+				onChange="document.content.acronymSelector.selectedIndex=document.content.termSelector.selectedIndex;
+					document.content.title.value=document.content.termSelector.options[document.content.termSelector.selectedIndex].value;
+					rtehtmlareaAcronymSelectedLanguage(document.content.title.value);">
+				<option value=""></option>
+			</select>
+		</div>
+		<div>
+			<label class="fl" for="acronymSelector" id="acronymSelectorLabel" title="' . $LANG->getLL('Select_an_acronym',1) . '">' . $LANG->getLL('Abridged_term',1) . '</label>
+			<select id="acronymSelector" name="acronymSelector"  title="' . $LANG->getLL('Select_an_acronym',1) . '"
+				onChange="document.content.termSelector.selectedIndex=document.content.acronymSelector.selectedIndex;
+					document.content.title.value=document.content.termSelector.options[document.content.termSelector.selectedIndex].value;
+					rtehtmlareaAcronymSelectedLanguage(document.content.title.value);">
+				<option value=""></option>
+			</select>
+		</div>
+		<div id="languageSelector">
+			<label class="fl" for="termLanguageSelector" id="termLanguageSelectorLabel" title="' . $LANG->getLL('Select_a_language',1) . '">' . $LANG->getLL('Language',1) . '</label>
+			<select id="termLanguageSelector" name="termLanguageSelector"  title="' . $LANG->getLL('Select_a_language',1) . '">
+			</select>
+		</div>
 	</fieldset>
 	<fieldset>
 		<legend>' . $LANG->getLL('Term_to_abridge',1) . '</legend>
@@ -276,4 +340,4 @@ if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/rtehtml
 	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/rtehtmlarea/mod2/class.tx_rtehtmlarea_acronym_mod.php']);
 }
 
-?>
+?>
\ No newline at end of file
